Option<T> class

Constructors

Option(String name, T defaultValue, String help, [String? abbr])

Properties

abbr → String?
final
defaultValue → T
final
hashCode → int
The hash code for this object.
no setterinherited
help → String
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ T
getter/setter pair

Methods

copy() → Option<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator +(Option<T> other) → Option<T>
operator ==(Object other) → bool
The equality operator.
inherited