Options class

Constructors

Options()

Properties

hashCode → int
The hash code for this object.
no setterinherited
options ↔ List<Option>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getOption<T>(String name) → Option<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setOption<T>(String name, T? value) → void
toString() → String
A string representation of this object.
override

Operators

operator +(Options other) → Options
operator ==(Object other) → bool
The equality operator.
inherited