Command class

Constructors

Command({Type? type, String? prefix, String? notprefix, String? command, required Callback callback})

Properties

callback → Callback
final
command → String?
final
hashCode → int
The hash code for this object.
no setterinherited
notprefix → String?
final
prefix → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → Type?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited