DartDeclaration class

Constructors

DartDeclaration()
DartDeclaration.fromCommand(List<Command> commandList, DartDeclaration self, {required String key, dynamic testSubject, dynamic value})
factory
DartDeclaration.fromKeyValue(String key, dynamic val)
factory

Properties

assignment ↔ String?
getter/setter pair
enumValues ↔ List<String>
getter/setter pair
explicitTypeOverride ↔ bool
getter/setter pair
extendsClass ↔ String?
getter/setter pair
fakerDeclaration ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ignored ↔ bool
getter/setter pair
imports ↔ List<String>
getter/setter pair
isDatetime → bool
no setter
isEnum → bool
no setter
isJsonable ↔ bool
getter/setter pair
isModel ↔ bool
getter/setter pair
isNullable ↔ bool
getter/setter pair
isNullableString → String
no setter
isTimeStamp → bool
no setter
jsonValue ↔ dynamic
getter/setter pair
mixinClass ↔ String?
getter/setter pair
name ↔ String?
getter/setter pair
nestedClasses ↔ List<JsonModel>
getter/setter pair
originalName ↔ String?
getter/setter pair
overrideEnabled ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
getter/setter pair

Methods

addImport(dynamic import) → void
checkNestedTypes(String type, NestedCallbackFunction callback) → String
copyWithBodyDeclaration() → String
copyWithConstructorDeclaration() → String
enableOverridden() → void
fromJsonBody() → String
getEnum(String className) → Enum
getImportStrings(String? relativePath) → List<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setEnumValues(List<String> values) → void
setIgnored() → void
setName(String name) → void
stringifyAssignment(String? value) → String
toCloneDeclaration() → String
toConstructor() → String
toDeclaration(String className) → String
toEquals() → String
toHash() → String
toJsonBody(String className) → String
toMockDeclaration(String className) → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getNameFromJsonKey(String theString) → String?
getParameterString(String theString) → String
getTypeFromJsonKey(String theString) → String?