Enum class

Constructors

Enum(String className, String name, List<String> values, {required bool isNullable})

Properties

className → String
final
converterName → String
no setter
enumName → String
no setter
enumValuesMapName → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
isNullable → bool
final
isNullableString → String
no setter
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → List<String>
final
valueType ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toImport() → String
toString() → String
A string representation of this object.
inherited
toTemplateString() → String
valueName(String input) → String
valuesForTemplate() → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited