JsonModel class

Constructors

JsonModel(String fileName, List<DartDeclaration> dartDeclarations, {String? packageName, String? indexPath, String? relativePath})
JsonModel.fromMap(String fileName, Map<String, dynamic> jsonMap, {String? packageName, String? indexPath, String? relativePath})
factory

Properties

className ↔ String
getter/setter pair
cloneFunction ↔ String
getter/setter pair
constructor ↔ String
getter/setter pair
copyWith ↔ String
getter/setter pair
declaration ↔ String
getter/setter pair
enumConverters ↔ String?
getter/setter pair
enums ↔ String?
getter/setter pair
equalsDeclarations ↔ String
getter/setter pair
extendsClass ↔ String?
getter/setter pair
fileName ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hashDeclarations ↔ String
getter/setter pair
imports ↔ String
getter/setter pair
indexPath ↔ String?
getter/setter pair
jsonFunctions ↔ String
getter/setter pair
mixinClass ↔ String
getter/setter pair
mockDeclaration ↔ String
getter/setter pair
nestedClasses ↔ String?
getter/setter pair
nestedFactoryClasses ↔ String?
getter/setter pair
packageName ↔ String?
getter/setter pair
relativePath ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited