FakerMaker class

Constructors

FakerMaker(DartDeclaration declaration, String className, String type, bool isModel)

Properties

className → String
final
declaration → DartDeclaration
final
hashCode → int
The hash code for this object.
no setterinherited
isModel → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final

Methods

createForDateTime(List<String> options) → String
createForInt(List<String> options) → String
createForString(List<String> options) → String
generate() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited